<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+88"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+76"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+107"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+103"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+79"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+115"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+105"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+104"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+105"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+91"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+89"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+92"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+76"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+70"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+106"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+88"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translation>Promień</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translation>Kąt początkowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translation>Kąt końcowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translation>Odwrócony</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translation>Średnica</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Łączna długość</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translation>Kąt</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Area</source>
        <translatorcomment>--google--
Obszar wieloboczny
Obszar &amp;wieloboczny
Mierzy obszar wieloboku</translatorcomment>
        <translation>Pole powierzchni</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Total Area</source>
        <translation>Łączne pole powierzchni</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="-1"/>
        <source>Circumference</source>
        <translation>Obwód</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translatorcomment>--google--
Wskaż położenie linii wymiarowej:
Wskaż położenie linii wymiarowej</translatorcomment>
        <translation>Linia wymiarowa</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translatorcomment>--google--
Punkt 1 rozszerzenia|X
Punkt 1 rozszerzenia|Y</translatorcomment>
        <translation>Punkt linii pomocniczej 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translatorcomment>--google--
Punkt 2 rozszerzenia|X
Punkt 2 rozszerzenia|Y</translatorcomment>
        <translation>Punkt linii pomocniczej 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translation>Początek linii 1</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translation>Koniec linii 1</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translation>Początek linii 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translation>Koniec linii 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translatorcomment>--google--
Wskaż położenie linii wymiarowej łuku</translatorcomment>
        <translation>Wymiar łuku</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punkt cięciwy</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odległy punkt cięciwy</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-5"/>
        <location line="+1"/>
        <source>Origin</source>
        <translatorcomment>--google--
Wskaż początek pierwszej linii rozszerzenia
Wskaż początek drugiej linii rozszerzenia
&amp;Usuń oryginał</translatorcomment>
        <translation>Początek układu współrzędnych</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translation>Rzędna</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Definiowanie punktu</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punkt końcowy odnośnika</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+121"/>
        <source>Dimension Angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Kąt wymiaru</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-8"/>
        <source>Label</source>
        <translation>Etykieta</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translation>Tolerancja</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Górna odchyłka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dolna odchyłka</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punkt definicji</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Położenie tekstu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Flip First Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Fixed Extension Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension Line Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Auto Label</source>
        <translation>Automatyczna etykieta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Measured Value</source>
        <translation>Zmierzona wartość</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear Factor</source>
        <translation>Współczynnik liniowy</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block Name</source>
        <translation>Nazwa bloku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Położenie automatycznej etykiety</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translatorcomment>--google--
Punkt główny|X
Punkt główny|Y</translatorcomment>
        <translation>Główny punkt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translation>Proporcja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translation>Parametr początkowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translation>Parametr końcowy</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-9"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translation>Punkt początkowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translation>Punkt końcowy</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-8"/>
        <source>Solid</source>
        <translation>Jednolity</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Wzór</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>Z obiektu</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+14"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translation>Kąt</translation>
    </message>
    <message>
        <location line="+192"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-191"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+2"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translation>Wierzchołek</translation>
    </message>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="-18"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Położenie</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Współczynnik szerokości</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Współczynnik wysokości</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width</source>
        <translation>Szerokość</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height</source>
        <translation>Wysokość</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Zanikanie</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <source>Arrow</source>
        <translation>Strzałka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Blok strzałki</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation type="vanished">W prawo</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation type="vanished">W lewo</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-9"/>
        <source>Polyline Pattern</source>
        <translation type="unfinished">Wzór linii łamanej</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translation>Zamknięta</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Bulge</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wybrzuszenie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start Width</source>
        <translation>Początkowa szerokość</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Końcowa szerokość</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Ogólna szerokość</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Orientacja</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Base Angle</source>
        <translation type="unfinished">Kąt podstawy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Z</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Punkt 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Punkt 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translation>Punkt 3</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translation>Punkt 4</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
        <source>Closed Periodic</source>
        <translation>Zamknięty okresowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Liczba stopni</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt kontrolny
Wskaż następny punkt kontrolny lub [%1]
Wskaż następny punkt kontrolny</translatorcomment>
        <translation>Punkt kontrolny</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punkt dopasowania</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Wektor węzła</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Węzeł</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use Start Tangent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simple</source>
        <translation type="vanished">Prosta</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation type="obsolete">Spis treści</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Tekst</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation type="vanished">Zwykły tekst</translation>
    </message>
    <message>
        <source>Font Name</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nazwa czcionki</translation>
    </message>
    <message>
        <source>Text Height</source>
        <translation type="vanished">Wysokość tekstu</translation>
    </message>
    <message>
        <source>Text Angle</source>
        <translation type="vanished">Kąt tekstu</translation>
    </message>
    <message>
        <source>X Scale</source>
        <translation type="vanished">Skala X</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Pogrubienie</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Kursywa</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation type="vanished">Odstęp między wierszami</translation>
    </message>
    <message>
        <source>Alignment</source>
        <translation type="vanished">Wyrównanie</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="vanished">Poziomo</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="vanished">Pionowo</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+89"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+89"/>
        <source>Tag</source>
        <translation>Etykieta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translation>Podpowiedź</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Punkt bazowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Drugi punkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Kierunek</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Stały kąt</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+1"/>
        <source>Invisible</source>
        <translation>Niewidoczny</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+141"/>
        <source>Arc Symbol Type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
